Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2338)

Unified Diff: Source/web/ChromeClientImpl.cpp

Issue 1149093010: Cleanup: Rename ChromeClient function names. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/web/ChromeClientImpl.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/web/ChromeClientImpl.cpp
diff --git a/Source/web/ChromeClientImpl.cpp b/Source/web/ChromeClientImpl.cpp
index b55de1bfdb16761196fa724c9c2cbdd9f7b14f6d..4467b5d5a09cef01ba17971489cc894f5823d177 100644
--- a/Source/web/ChromeClientImpl.cpp
+++ b/Source/web/ChromeClientImpl.cpp
@@ -370,12 +370,12 @@ void ChromeClientImpl::addMessageToConsole(LocalFrame* localFrame, MessageSource
}
}
-bool ChromeClientImpl::canRunBeforeUnloadConfirmPanel()
+bool ChromeClientImpl::canOpenBeforeUnloadConfirmPanel()
{
return !!m_webView->client();
}
-bool ChromeClientImpl::runBeforeUnloadConfirmPanelInternal(LocalFrame* frame, const String& message)
+bool ChromeClientImpl::openBeforeUnloadConfirmPanelDelegate(LocalFrame* frame, const String& message)
{
notifyPopupOpeningObservers();
WebLocalFrameImpl* webframe = WebLocalFrameImpl::fromFrame(frame);
@@ -402,7 +402,7 @@ void ChromeClientImpl::closeWindowSoon()
// Although a LocalFrame is passed in, we don't actually use it, since we
// already know our own m_webView.
-void ChromeClientImpl::runJavaScriptAlertInternal(LocalFrame* frame, const String& message)
+void ChromeClientImpl::openJavaScriptAlertDelegate(LocalFrame* frame, const String& message)
{
notifyPopupOpeningObservers();
WebLocalFrameImpl* webframe = WebLocalFrameImpl::fromFrame(frame);
@@ -413,8 +413,8 @@ void ChromeClientImpl::runJavaScriptAlertInternal(LocalFrame* frame, const Strin
}
}
-// See comments for runJavaScriptAlert().
-bool ChromeClientImpl::runJavaScriptConfirmInternal(LocalFrame* frame, const String& message)
+// See comments for openJavaScriptAlertDelegate().
+bool ChromeClientImpl::openJavaScriptConfirmDelegate(LocalFrame* frame, const String& message)
{
notifyPopupOpeningObservers();
WebLocalFrameImpl* webframe = WebLocalFrameImpl::fromFrame(frame);
@@ -426,8 +426,8 @@ bool ChromeClientImpl::runJavaScriptConfirmInternal(LocalFrame* frame, const Str
return false;
}
-// See comments for runJavaScriptAlert().
-bool ChromeClientImpl::runJavaScriptPromptInternal(LocalFrame* frame, const String& message, const String& defaultValue, String& result)
+// See comments for openJavaScriptAlertDelegate().
+bool ChromeClientImpl::openJavaScriptPromptDelegate(LocalFrame* frame, const String& message, const String& defaultValue, String& result)
{
notifyPopupOpeningObservers();
WebLocalFrameImpl* webframe = WebLocalFrameImpl::fromFrame(frame);
@@ -561,13 +561,13 @@ void ChromeClientImpl::dispatchViewportPropertiesDidChange(const ViewportDescrip
m_webView->updatePageDefinedViewportConstraints(description);
}
-void ChromeClientImpl::printInternal(LocalFrame* frame)
+void ChromeClientImpl::printDelegate(LocalFrame* frame)
{
if (m_webView->client())
m_webView->client()->printPage(WebLocalFrameImpl::fromFrame(frame));
}
-PassOwnPtrWillBeRawPtr<ColorChooser> ChromeClientImpl::createColorChooser(LocalFrame* frame, ColorChooserClient* chooserClient, const Color&)
+PassOwnPtrWillBeRawPtr<ColorChooser> ChromeClientImpl::openColorChooser(LocalFrame* frame, ColorChooserClient* chooserClient, const Color&)
{
notifyPopupOpeningObservers();
OwnPtrWillBeRawPtr<ColorChooserUIController> controller = nullptr;
@@ -589,7 +589,7 @@ PassRefPtr<DateTimeChooser> ChromeClientImpl::openDateTimeChooser(DateTimeChoose
#endif
}
-void ChromeClientImpl::runOpenPanel(LocalFrame* frame, PassRefPtr<FileChooser> fileChooser)
+void ChromeClientImpl::openFileChooser(LocalFrame* frame, PassRefPtr<FileChooser> fileChooser)
{
notifyPopupOpeningObservers();
WebViewClient* client = m_webView->client();
@@ -767,7 +767,7 @@ bool ChromeClientImpl::hasOpenedPopup() const
return m_webView->hasOpenedPopup();
}
-PassRefPtrWillBeRawPtr<PopupMenu> ChromeClientImpl::createPopupMenu(LocalFrame& frame, PopupMenuClient* client)
+PassRefPtrWillBeRawPtr<PopupMenu> ChromeClientImpl::openPopupMenu(LocalFrame& frame, PopupMenuClient* client)
{
notifyPopupOpeningObservers();
if (WebViewImpl::useExternalPopupMenus())
@@ -794,7 +794,7 @@ DOMWindow* ChromeClientImpl::pagePopupWindowForTesting() const
return m_webView->pagePopupWindow();
}
-bool ChromeClientImpl::shouldRunModalDialogDuringPageDismissal(const DialogType& dialogType, const String& dialogMessage, Document::PageDismissalType dismissalType) const
+bool ChromeClientImpl::shouldOpenModalDialogDuringPageDismissal(const DialogType& dialogType, const String& dialogMessage, Document::PageDismissalType dismissalType) const
{
const char* kDialogs[] = {"alert", "confirm", "prompt"};
int dialog = static_cast<int>(dialogType);
« no previous file with comments | « Source/web/ChromeClientImpl.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698